==> apo-ws-client-6.00.10.2-sources.jar: fr/univlorraine/apowsclient/creationSE/DiplomeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DiplomeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DiplomeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="licDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libDip" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codNdi"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codCycle"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codTypDip"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureSS" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureAccTrv" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codSecteurDiscipl" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="4"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codNim" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtb" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="listGroupesDip" type="{DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ListeGroupeDiplomeDTO" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DiplomeDTO", namespace = "DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codDip",
    "licDip",
    "libDip",
    "codNdi",
    "codCycle",
    "codTypDip",
    "temCouvertureSS",
    "temCouvertureAccTrv",
    "codSecteurDiscipl",
    "codNim",
    "codEtb",
    "listGroupesDip"
})
public class DiplomeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codDip;
    @XmlElement(required = true, nillable = true)
    protected String licDip;
    @XmlElementRef(name = "libDip", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libDip;
    @XmlElement(required = true, nillable = true)
    protected String codNdi;
    @XmlElement(required = true, nillable = true)
    protected String codCycle;
    @XmlElement(required = true, nillable = true)
    protected String codTypDip;
    @XmlElementRef(name = "temCouvertureSS", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temCouvertureSS;
    @XmlElementRef(name = "temCouvertureAccTrv", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temCouvertureAccTrv;
    @XmlElementRef(name = "codSecteurDiscipl", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codSecteurDiscipl;
    @XmlElementRef(name = "codNim", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codNim;
    @XmlElementRef(name = "codEtb", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codEtb;
    @XmlElementRef(name = "listGroupesDip", type = JAXBElement.class, required = false)
    protected JAXBElement<ListeGroupeDiplomeDTO> listGroupesDip;

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété licDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLicDip() {
        return licDip;
    }

    /**
     * Définit la valeur de la propriété licDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLicDip(String value) {
        this.licDip = value;
    }

    /**
     * Obtient la valeur de la propriété libDip.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibDip() {
        return libDip;
    }

    /**
     * Définit la valeur de la propriété libDip.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibDip(JAXBElement<String> value) {
        this.libDip = value;
    }

    /**
     * Obtient la valeur de la propriété codNdi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodNdi() {
        return codNdi;
    }

    /**
     * Définit la valeur de la propriété codNdi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodNdi(String value) {
        this.codNdi = value;
    }

    /**
     * Obtient la valeur de la propriété codCycle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCycle() {
        return codCycle;
    }

    /**
     * Définit la valeur de la propriété codCycle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCycle(String value) {
        this.codCycle = value;
    }

    /**
     * Obtient la valeur de la propriété codTypDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTypDip() {
        return codTypDip;
    }

    /**
     * Définit la valeur de la propriété codTypDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTypDip(String value) {
        this.codTypDip = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureSS.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemCouvertureSS() {
        return temCouvertureSS;
    }

    /**
     * Définit la valeur de la propriété temCouvertureSS.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemCouvertureSS(JAXBElement<String> value) {
        this.temCouvertureSS = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureAccTrv.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemCouvertureAccTrv() {
        return temCouvertureAccTrv;
    }

    /**
     * Définit la valeur de la propriété temCouvertureAccTrv.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemCouvertureAccTrv(JAXBElement<String> value) {
        this.temCouvertureAccTrv = value;
    }

    /**
     * Obtient la valeur de la propriété codSecteurDiscipl.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodSecteurDiscipl() {
        return codSecteurDiscipl;
    }

    /**
     * Définit la valeur de la propriété codSecteurDiscipl.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodSecteurDiscipl(JAXBElement<String> value) {
        this.codSecteurDiscipl = value;
    }

    /**
     * Obtient la valeur de la propriété codNim.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodNim() {
        return codNim;
    }

    /**
     * Définit la valeur de la propriété codNim.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodNim(JAXBElement<String> value) {
        this.codNim = value;
    }

    /**
     * Obtient la valeur de la propriété codEtb.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodEtb() {
        return codEtb;
    }

    /**
     * Définit la valeur de la propriété codEtb.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodEtb(JAXBElement<String> value) {
        this.codEtb = value;
    }

    /**
     * Obtient la valeur de la propriété listGroupesDip.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ListeGroupeDiplomeDTO }{@code >}
     *     
     */
    public JAXBElement<ListeGroupeDiplomeDTO> getListGroupesDip() {
        return listGroupesDip;
    }

    /**
     * Définit la valeur de la propriété listGroupesDip.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ListeGroupeDiplomeDTO }{@code >}
     *     
     */
    public void setListGroupesDip(JAXBElement<ListeGroupeDiplomeDTO> value) {
        this.listGroupesDip = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/DiplomeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DiplomeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DiplomeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="licDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libDip" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codNdi"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codCycle"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codTypDip"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureSS" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureAccTrv" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codSecteurDiscipl" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="4"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codNim" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtb" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="listGroupesDip" type="{DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ListeGroupeDiplomeDTO" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DiplomeDTO", namespace = "DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codDip",
    "licDip",
    "libDip",
    "codNdi",
    "codCycle",
    "codTypDip",
    "temCouvertureSS",
    "temCouvertureAccTrv",
    "codSecteurDiscipl",
    "codNim",
    "codEtb",
    "listGroupesDip"
})
public class DiplomeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codDip;
    @XmlElement(required = true, nillable = true)
    protected String licDip;
    @XmlElement(nillable = true)
    protected String libDip;
    @XmlElement(required = true, nillable = true)
    protected String codNdi;
    @XmlElement(required = true, nillable = true)
    protected String codCycle;
    @XmlElement(required = true, nillable = true)
    protected String codTypDip;
    @XmlElement(nillable = true)
    protected String temCouvertureSS;
    @XmlElement(nillable = true)
    protected String temCouvertureAccTrv;
    @XmlElement(nillable = true)
    protected String codSecteurDiscipl;
    @XmlElement(nillable = true)
    protected String codNim;
    @XmlElement(nillable = true)
    protected String codEtb;
    @XmlElement(nillable = true)
    protected ListeGroupeDiplomeDTO listGroupesDip;

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété licDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLicDip() {
        return licDip;
    }

    /**
     * Définit la valeur de la propriété licDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLicDip(String value) {
        this.licDip = value;
    }

    /**
     * Obtient la valeur de la propriété libDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibDip() {
        return libDip;
    }

    /**
     * Définit la valeur de la propriété libDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibDip(String value) {
        this.libDip = value;
    }

    /**
     * Obtient la valeur de la propriété codNdi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodNdi() {
        return codNdi;
    }

    /**
     * Définit la valeur de la propriété codNdi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodNdi(String value) {
        this.codNdi = value;
    }

    /**
     * Obtient la valeur de la propriété codCycle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCycle() {
        return codCycle;
    }

    /**
     * Définit la valeur de la propriété codCycle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCycle(String value) {
        this.codCycle = value;
    }

    /**
     * Obtient la valeur de la propriété codTypDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTypDip() {
        return codTypDip;
    }

    /**
     * Définit la valeur de la propriété codTypDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTypDip(String value) {
        this.codTypDip = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureSS.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemCouvertureSS() {
        return temCouvertureSS;
    }

    /**
     * Définit la valeur de la propriété temCouvertureSS.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemCouvertureSS(String value) {
        this.temCouvertureSS = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureAccTrv.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemCouvertureAccTrv() {
        return temCouvertureAccTrv;
    }

    /**
     * Définit la valeur de la propriété temCouvertureAccTrv.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemCouvertureAccTrv(String value) {
        this.temCouvertureAccTrv = value;
    }

    /**
     * Obtient la valeur de la propriété codSecteurDiscipl.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSecteurDiscipl() {
        return codSecteurDiscipl;
    }

    /**
     * Définit la valeur de la propriété codSecteurDiscipl.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSecteurDiscipl(String value) {
        this.codSecteurDiscipl = value;
    }

    /**
     * Obtient la valeur de la propriété codNim.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodNim() {
        return codNim;
    }

    /**
     * Définit la valeur de la propriété codNim.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodNim(String value) {
        this.codNim = value;
    }

    /**
     * Obtient la valeur de la propriété codEtb.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtb() {
        return codEtb;
    }

    /**
     * Définit la valeur de la propriété codEtb.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtb(String value) {
        this.codEtb = value;
    }

    /**
     * Obtient la valeur de la propriété listGroupesDip.
     * 
     * @return
     *     possible object is
     *     {@link ListeGroupeDiplomeDTO }
     *     
     */
    public ListeGroupeDiplomeDTO getListGroupesDip() {
        return listGroupesDip;
    }

    /**
     * Définit la valeur de la propriété listGroupesDip.
     * 
     * @param value
     *     allowed object is
     *     {@link ListeGroupeDiplomeDTO }
     *     
     */
    public void setListGroupesDip(ListeGroupeDiplomeDTO value) {
        this.listGroupesDip = value;
    }

}
